@@ -110,6 +110,14 @@ impl Message {
     as_value_ref!(as_map, [MapEntry], Map);
     as_value_ref!(as_extension, Extension, Extension);
 
+    /// Return `true` if the message is nil
+    pub const fn is_nil(&self) -> bool {
+        match self {
+            Self::Nil => true,
+            _ => false,
+        }
+    }
+
     /// Create a new unsigned interger
     pub fn integer_unsigned<T>(n: T) -> Self
     where
